# Requirements

This is a list of maintained python dependencies for the project.

### Runtime dependencies

`deploifai` core dependencies

```text
requests
azure-identity
azure-storage-blob
boto3
google-auth
google-cloud-storage
semver
cryptography
docker
```

### CLI dependencies

`cli` module dependencies for the CLI tool

```text
click
click-spinner
InquirerPy
keyring
tqdm
pyperclip
python-dotenv
```

### Dev dependencies

These are the dependencies required for development and testing.

```text
black
setuptools-scm
twine
build
mkdocs
mkdocs-click
```
